### 🚀 Features

- *(config)* Replace `pydantic` with `msgspec`

### ⚙️ Miscellaneous Tasks

- *(release)* Automate the releases
- *(changelog)* Update changelog with links to tags
- *(docs)* Build documentation in the same CI job
- *(gh-actions)* Build docs and test after pre-commit completes
- *(docs)* Build and publish docs as the final step
- *(cleanup)* Fix cache keys and other minor cleanups
- *(release)* Don't echo the multiline changelog string

